FlipBitFlag class abstract

Implemented types
Annotations
  • @immutable

Constructors

FlipBitFlag()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
otherSide IBitFlag
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Returns the value of the flag, if the class is FlipBitFlag, the value is always zero.
no setteroverride

Methods

extract(IBitFlag mask) IBitFlag
Returns flag and keeps the bit that matches the 1-bit in the mask. All of the other bits will be set to 0.
inherited
hasFlag(IBitFlag flag) bool
Returns true if the origin contains the flag. If the flag is a FlipBitFlag, the result will be true when the origin does not contain flag.otherSide.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBinaryString([int width]) String
Returns the value of origin as String with the binary base. If the width is not set, the bit length will be auto-set.
inherited
toFlip() IBitFlag
Flip the flag. If the origin is a FlipBitFlag, the result will be a normal BitFlag. Otherwise, the result will be changed to FlipBitFlag.
inherited
toggle(IBitFlag mask) IBitFlag
Toggle the bit that matches the 1-bit in the mask.
inherited
toRadixString(int radix, [int width]) String
Returns the value of origin as String with the radix.
inherited
toString() String
A string representation of this object.
override

Operators

operator &(covariant IBitFlag other) IBitFlag
AND (Bitwise) two values of this and other. If both this and other are FlipBitFlag, the result will be a FlipBitFlag too.
inherited
operator <<(int other) IBitFlag
SHIFT LEFT (Bitwise) two values of this and other. If both this and other are FlipBitFlag, the result will be a FlipBitFlag too.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator >>(int other) IBitFlag
SHIFT RIGHT (Bitwise) two values of this and other. If both this and other are FlipBitFlag, the result will be a FlipBitFlag too.
inherited
operator ^(covariant IBitFlag other) IBitFlag
XOR (Bitwise) two values of this and other. If both this and other are FlipBitFlag, the result will be a FlipBitFlag too.
inherited
operator |(covariant IBitFlag other) IBitFlag
OR (Bitwise) two values of this and other. If both this and other are FlipBitFlag, the result will be a FlipBitFlag too.
inherited