- Implemented types
-
- Annotations
-
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
otherSide
→ IBitFlag
-
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ int
-
Returns the value of the flag, if the class is FlipBitFlag, the value is always zero.
no setteroverride
Methods
-
Returns flag and keeps the bit that matches the 1-bit in the
mask. All of the other bits will be set to 0.
inherited
-
hasFlag(IBitFlag flag)
→ bool
-
Returns true if the
origin contains the flag.
If the flag is a FlipBitFlag, the result will be true when the origin does not contain flag.otherSide.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toBinaryString([int width])
→ String
-
Returns the value of
origin as String with the binary base.
If the width is not set, the bit length will be auto-set.
inherited
-
toFlip()
→ IBitFlag
-
Flip the flag. If the
origin is a FlipBitFlag, the result will be a normal BitFlag.
Otherwise, the result will be changed to FlipBitFlag.
inherited
-
toggle(IBitFlag mask)
→ IBitFlag
-
Toggle the bit that matches the 1-bit in the mask.
inherited
-
toRadixString(int radix, [int width])
→ String
-
Returns the value of
origin as String with the radix.
inherited
-
toString()
→ String
-
A string representation of this object.
override